<?php

defined('ABSPATH') or die;

/*
 * 
 * Require the framework class before doing anything else, so we can use the defined urls and dirs
 *
 */
require_once( dirname( __FILE__ ) . '/options/options.php' );

/*
 * 
 * Add support tab
 *
 */
if ( ! defined('MTS_THEME_WHITE_LABEL') || ! MTS_THEME_WHITE_LABEL ) {
	require_once( dirname( __FILE__ ) . '/options/support.php' );
	$mts_options_tab_support = MTS_Options_Tab_Support::get_instance();
}

/*
 * 
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constansts for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
 */
function add_another_section($sections){
	
	//$sections = array();
	$sections[] = array(
				'title' => __('A Section added by hook', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description">This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.</p>', MTS_THEME_TEXTDOMAIN ),
				//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
				//You dont have to though, leave it blank for default.
				'icon' => trailingslashit(get_template_directory_uri()).'options/img/glyphicons/glyphicons_062_attach.png',
				//Lets leave this as a blank section, no options just some intro text set above.
				'fields' => array()
				);
	
	return $sections;
	
}//function
//add_filter('nhp-opts-sections-twenty_eleven', 'add_another_section');


/*
 * 
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
 */
function change_framework_args($args){
	
	//$args['dev_mode'] = false;
	
	return $args;
	
}//function
//add_filter('nhp-opts-args-twenty_eleven', 'change_framework_args');

/*
 * This is the meat of creating the optons page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but there there to be over ridden if needed.
 *
 *
 */

function setup_framework_options(){
$args = array();

//Set it to dev mode to view the class settings/info in the form - default is false
$args['dev_mode'] = false;
//Remove the default stylesheet? make sure you enqueue another one all the page will look whack!
//$args['stylesheet_override'] = true;

//Add HTML before the form
//$args['intro_text'] = __('<p>This is the HTML which can be displayed before the form, it isnt required, but more info is always better. Anything goes in terms of markup here, any HTML.</p>', MTS_THEME_TEXTDOMAIN );

//Setup custom links in the footer for share icons
$args['share_icons']['twitter'] = array(
										'link' => 'http://twitter.com/mythemeshopteam',
										'title' => 'Follow Us on Twitter', 
										'img' => 'fa fa-twitter-square'
										);
$args['share_icons']['facebook'] = array(
										'link' => 'http://www.facebook.com/mythemeshop',
										'title' => 'Like us on Facebook', 
										'img' => 'fa fa-facebook-square'
										);

//Choose to disable the import/export feature
//$args['show_import_export'] = false;

//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
$args['opt_name'] = MTS_THEME_NAME;

//Custom menu icon
//$args['menu_icon'] = '';

//Custom menu title for options page - default is "Options"
$args['menu_title'] = __('Theme Options', MTS_THEME_TEXTDOMAIN );

//Custom Page Title for options page - default is "Options"
$args['page_title'] = __('Theme Options', MTS_THEME_TEXTDOMAIN );

//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "nhp_theme_options"
$args['page_slug'] = 'theme_options';

//Custom page capability - default is set to "manage_options"
//$args['page_cap'] = 'manage_options';

//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
//$args['page_type'] = 'submenu';

//parent menu - default is set to "themes.php" (Appearance)
//the list of available parent menus is available here: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
//$args['page_parent'] = 'themes.php';

//custom page location - default 100 - must be unique or will override other items
$args['page_position'] = 62;

//Custom page icon class (used to override the page icon next to heading)
//$args['page_icon'] = 'icon-themes';
		
//Set ANY custom page help tabs - displayed using the new help tab API, show in order of definition		
$args['help_tabs'][] = array(
							'id' => 'nhp-opts-1',
							'title' => __('Support', MTS_THEME_TEXTDOMAIN ),
							'content' => __('<p>If you are facing any problem with our theme or theme option panel, head over to our <a href="http://community.mythemeshop.com/">Support Forums.</a></p>', MTS_THEME_TEXTDOMAIN )
							);
$args['help_tabs'][] = array(
							'id' => 'nhp-opts-2',
							'title' => __('Earn Money', MTS_THEME_TEXTDOMAIN ),
							'content' => __('<p>Earn 70% commision on every sale by refering your friends and readers. Join our <a href="http://mythemeshop.com/affiliate-program/">Affiliate Program</a>.</p>', MTS_THEME_TEXTDOMAIN )
							);

//Set the Help Sidebar for the options page - no sidebar by default										
//$args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', MTS_THEME_TEXTDOMAIN );

$mts_patterns = array(
	'nobg' => array('img' => NHP_OPTIONS_URL.'img/patterns/nobg.png'),
	'pattern0' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern0.png'),
	'pattern1' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern1.png'),
	'pattern2' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern2.png'),
	'pattern3' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern3.png'),
	'pattern4' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern4.png'),
	'pattern5' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern5.png'),
	'pattern6' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern6.png'),
	'pattern7' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern7.png'),
	'pattern8' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern8.png'),
	'pattern9' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern9.png'),
	'pattern10' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern10.png'),
	'pattern11' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern11.png'),
	'pattern12' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern12.png'),
	'pattern13' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern13.png'),
	'pattern14' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern14.png'),
	'pattern15' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern15.png'),
	'pattern16' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern16.png'),
	'pattern17' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern17.png'),
	'pattern18' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern18.png'),
	'pattern19' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern19.png'),
	'pattern20' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern20.png'),
	'pattern21' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern21.png'),
	'pattern22' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern22.png'),
	'pattern23' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern23.png'),
	'pattern24' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern24.png'),
	'pattern25' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern25.png'),
	'pattern26' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern26.png'),
	'pattern27' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern27.png'),
	'pattern28' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern28.png'),
	'pattern29' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern29.png'),
	'pattern30' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern30.png'),
	'pattern31' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern31.png'),
	'pattern32' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern32.png'),
	'pattern33' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern33.png'),
	'pattern34' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern34.png'),
	'pattern35' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern35.png'),
	'pattern36' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern36.png'),
	'pattern37' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern37.png'),
	'hbg' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg.png'),
	'hbg2' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg2.png'),
	'hbg3' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg3.png'),
	'hbg4' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg4.png'),
	'hbg5' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg5.png'),
	'hbg6' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg6.png'),
	'hbg7' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg7.png'),
	'hbg8' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg8.png'),
	'hbg9' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg9.png'),
	'hbg10' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg10.png'),
	'hbg11' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg11.png'),
	'hbg12' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg12.png'),
	'hbg13' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg13.png'),
	'hbg14' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg14.png'),
	'hbg15' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg15.png'),
	'hbg16' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg16.png'),
	'hbg17' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg17.png'),
	'hbg18' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg18.png'),
	'hbg19' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg19.png'),
	'hbg20' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg20.png'),
	'hbg21' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg21.png'),
	'hbg22' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg22.png'),
	'hbg23' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg23.png'),
	'hbg24' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg24.png'),
	'hbg25' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg25.png')
);

$sections = array();

$sections[] = array(
				'icon' => 'fa fa-cogs',
				'title' => __('General Settings', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description">This tab contains common setting options which will be applied to the whole theme.</p>', MTS_THEME_TEXTDOMAIN ),
				'fields' => array(
					array(
						'id' => 'mts_logo',
						'type' => 'upload',
						'title' => __('Logo Image', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Upload your logo using the Upload Button or insert image URL.', MTS_THEME_TEXTDOMAIN )
						),
					array(
						'id' => 'mts_favicon',
						'type' => 'upload',
						'title' => __('Favicon', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Upload a <strong>32 x 32 px</strong> image that will represent your website\'s favicon.', MTS_THEME_TEXTDOMAIN )
						),
						array(
						'id' => 'mts_footer_logo',
						'type' => 'upload',
						'title' => __('Footer Logo Image', MTS_THEME_TEXTDOMAIN), 
						'sub_desc' => __('Upload your logo using the Upload Button or insert image URL.', MTS_THEME_TEXTDOMAIN)
						),
					array(
						'id' => 'mts_touch_icon',
						'type' => 'upload',
						'title' => __('Touch icon', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Upload a <strong>152 x 152 px</strong> image that will represent your website\'s touch icon for iOS 2.0+ and Android 2.1+ devices.', MTS_THEME_TEXTDOMAIN )
						),
					array(
						'id' => 'mts_metro_icon',
						'type' => 'upload',
						'title' => __('Metro icon', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Upload a <strong>144 x 144 px</strong> image that will represent your website\'s IE 10 Metro tile icon.', MTS_THEME_TEXTDOMAIN )
						),
					array(
						'id' => 'mts_twitter_username',
						'type' => 'text',
						'title' => __('Twitter Username', MTS_THEME_TEXTDOMAIN ),
						'sub_desc' => __('Enter your Username here.', MTS_THEME_TEXTDOMAIN ),
						),
					array(
						'id' => 'mts_feedburner',
						'type' => 'text',
						'title' => __('FeedBurner URL', MTS_THEME_TEXTDOMAIN ),
						'sub_desc' => __('Enter your FeedBurner\'s URL here, ex: <strong>http://feeds.feedburner.com/mythemeshop</strong> and your main feed (http://example.com/feed) will get redirected to the FeedBurner ID entered here.)', MTS_THEME_TEXTDOMAIN ),
						'validate' => 'url'
						),
					array(
						'id' => 'mts_header_code',
						'type' => 'textarea',
						'title' => __('Header Code', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Enter the code which you need to place <strong>before closing </head> tag</strong>. (ex: Google Webmaster Tools verification, Bing Webmaster Center, BuySellAds Script, Alexa verification etc.)', MTS_THEME_TEXTDOMAIN )
						),
					array(
						'id' => 'mts_analytics_code',
						'type' => 'textarea',
						'title' => __('Footer Code', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Enter the codes which you need to place in your footer. <strong>(ex: Google Analytics, Clicky, STATCOUNTER, Woopra, Histats, etc.)</strong>.', MTS_THEME_TEXTDOMAIN )
						),
					array(
						'id' => 'mts_copyrights',
						'type' => 'textarea',
						'title' => __('Copyrights Text', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('You can change or remove our link from footer and use your own custom text. (Link back is always appreciated)', MTS_THEME_TEXTDOMAIN ),
						'std' => 'Theme by <a href="http://mythemeshop.com/" rel="nofollow">MyThemeShop</a>'
						),
					array(
                        'id' => 'mts_pagenavigation_type',
                        'type' => 'radio',
                        'title' => __('Pagination Type', MTS_THEME_TEXTDOMAIN ),
                        'sub_desc' => __('Select pagination type.', MTS_THEME_TEXTDOMAIN ),
                        'options' => array(
                                        '0'=> __('Default (Next / Previous)', MTS_THEME_TEXTDOMAIN ), 
                                        '1' => __('Numbered (1 2 3 4...)', MTS_THEME_TEXTDOMAIN ), 
                                        '2' => 'AJAX (Load More Button)', 
                                        '3' => 'AJAX (Auto Infinite Scroll)'),
                        'std' => '1'
                        ),
                    array(
                        'id' => 'mts_ajax_search',
                        'type' => 'button_set',
                        'title' => __('AJAX Quick search', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Enable or disable search results appearing instantly below the search form', MTS_THEME_TEXTDOMAIN ),
						'std' => '0'
                        ),
                    array(
                        'id' => 'mts_total_views',
                        'type' => 'button_set',
                        'title' => __('Show Post Views', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Show or Hide total post views on homepage and single articles.', MTS_THEME_TEXTDOMAIN ),
						'std' => '1'
                        ),
					array(
						'id' => 'mts_responsive',
						'type' => 'button_set',
						'title' => __('Responsiveness', MTS_THEME_TEXTDOMAIN ),
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('MyThemeShop themes are responsive, which means they adapt to tablet and mobile devices, ensuring that your content is always displayed beautifully no matter what device visitors are using. Enable or disable responsiveness using this option.', MTS_THEME_TEXTDOMAIN ),
						'std' => '1'
						),
					array(
						'id' => 'mts_prefetching',
						'type' => 'button_set',
						'title' => __('Prefetching', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Enable or disable prefetching. If user is on homepage, then single page will load faster and if user is on single page, homepage will load faster in modern browsers.', MTS_THEME_TEXTDOMAIN ),
						'std' => '0'
						),
					array(
						'id' => 'mts_lazy_load',
						'type' => 'button_set_hide_below',
						'title' => __('Lazy Load', MTS_THEME_TEXTDOMAIN ),
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Delay loading of images outside of viewport, until user scrolls to them.', MTS_THEME_TEXTDOMAIN ),
						'options' => array(
										'0' => 'Off',
										'1' => 'On'
											),
						'std' => '0',
						'args' => array('hide' => 2)
						),
					array(
						'id' => 'mts_lazy_load_thumbs',
						'type' => 'button_set',
						'title' => __('Lazy load fatured images', MTS_THEME_TEXTDOMAIN ),
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Enable or disable Lazy load of featured images across site.', MTS_THEME_TEXTDOMAIN ),
						'std' => '0'
						),
					array(
						'id' => 'mts_lazy_load_content',
						'type' => 'button_set',
						'title' => __('Lazy load post content images', MTS_THEME_TEXTDOMAIN ),
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Enable or disable Lazy load of images inside post/page content.', MTS_THEME_TEXTDOMAIN ),
						'std' => '0'
						),
					array(
						'id' => 'mts_rtl',
						'type' => 'button_set',
						'title' => __('Right To Left Language Support', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Enable this option for right-to-left sites.', MTS_THEME_TEXTDOMAIN ),
						'std' => '0'
						),
					)
				);
$sections[] = array(
				'icon' => 'fa fa-adjust',
				'title' => __('Styling Options', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description">Control the visual appearance of your theme, such as colors, layout and patterns, from here.</p>', MTS_THEME_TEXTDOMAIN ),
				'fields' => array(
					array(
						'id' => 'mts_color_scheme',
						'type' => 'color',
						'title' => __('Color Scheme', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('The theme comes with unlimited color schemes for your theme\'s styling.', MTS_THEME_TEXTDOMAIN ),
						'std' => '#ffa312'
						),
					array(
						'id' => 'mts_layout',
						'type' => 'radio_img',
						'title' => __('Layout Style', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Choose the <strong>default sidebar position</strong> for your site. The position of the sidebar for individual posts can be set in the post editor.', MTS_THEME_TEXTDOMAIN ),
						'options' => array(
										'cslayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/cs.png'),
										'sclayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/sc.png')
											),
						'std' => 'cslayout'
						),
                    array(
						'id' => 'mts_first_footer',
						'type' => 'button_set_hide_below',
						'title' => __('Footer Widgets', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Enable or disable footer widgets with this option.', MTS_THEME_TEXTDOMAIN ),
						'options' => array(
										'0' => 'Off',
										'1' => 'On'
											),
						'std' => '0'
						),
                        array(
						'id' => 'mts_first_footer_num',
						'type' => 'button_set',
                        'class' => 'green',
						'title' => __('Footer Widget Columns', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Choose the number of widget columns in the <strong>footer</strong>', MTS_THEME_TEXTDOMAIN ),
						'options' => array(
										'3' => __('3 Widgets', MTS_THEME_TEXTDOMAIN),
										'4' => __('4 Widgets', MTS_THEME_TEXTDOMAIN)
											),
						'std' => '3'
						),
					array(
						'id' => 'mts_bg_color',
						'type' => 'color',
						'title' => __('Background Color', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Pick a color for the site background color.', MTS_THEME_TEXTDOMAIN ),
						'std' => '#ffffff'
						),
					array(
						'id' => 'mts_bg_pattern',
						'type' => 'radio_img',
						'title' => __('Background Pattern', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Choose from any of <strong>63</strong> awesome background patterns for your site\'s background.', MTS_THEME_TEXTDOMAIN ),
						'options' => $mts_patterns,
						'std' => 'nobg'
						),
					array(
						'id' => 'mts_bg_pattern_upload',
						'type' => 'upload',
						'title' => __('Custom Background Image', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Upload your own custom background image or pattern.', MTS_THEME_TEXTDOMAIN )
						),
					array(
						'id' => 'mts_footer_color_scheme',
						'type' => 'color',
						'title' => __('Footer Color Scheme', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('The theme comes with unlimited color schemes for your footer\'s styling.', MTS_THEME_TEXTDOMAIN ),
						'std' => '#e9e9e9'
						),
					array(
						'id' => 'mts_custom_css',
						'type' => 'textarea',
						'title' => __('Custom CSS', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('You can enter custom CSS code here to further customize your theme. This will override the default CSS used on your site.', MTS_THEME_TEXTDOMAIN )
						),
					array(
						'id' => 'mts_lightbox',
						'type' => 'button_set',
						'title' => __('Lightbox', MTS_THEME_TEXTDOMAIN ),
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('A lightbox is a stylized pop-up that allows your visitors to view larger versions of images without leaving the current page. You can enable or disable the lightbox here.', MTS_THEME_TEXTDOMAIN ),
						'std' => '0'
						),
					)
				);
$sections[] = array(
				'icon' => 'fa fa-credit-card',
				'title' => __('Header', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description">From here, you can control the elements of header section.</p>', MTS_THEME_TEXTDOMAIN ),
				'fields' => array(
					array(
						'id' => 'mts_sticky_nav',
						'type' => 'button_set',
						'title' => __('Floating Navigation Menu', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Use this button to enable <strong>Floating Navigation Menu</strong>.', MTS_THEME_TEXTDOMAIN ),
						'std' => '0'
						),
                    array(
						'id' => 'mts_show_primary_nav',
						'type' => 'button_set',
						'title' => __('Show Primary Menu', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Use this button to enable <strong>Primary Navigation Menu</strong>.', MTS_THEME_TEXTDOMAIN ),
						'std' => '1'
						),
                    array(
						'id' => 'mts_nav_color_scheme',
						'type' => 'color',
						'title' => __('Menu Color Scheme', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('The theme comes with unlimited color schemes for your menu\'s styling.', MTS_THEME_TEXTDOMAIN ),
						'std' => '#dadada'
						),
					array(
						'id' => 'mts_header_section2',
						'type' => 'button_set',
						'title' => __('Show Logo', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Use this button to Show or Hide <strong>Logo</strong> completely.', MTS_THEME_TEXTDOMAIN ),
						'std' => '1'
						),
					)
				);	
$sections[] = array(
				'icon' => 'fa fa-home',
				'title' => __('Homepage', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description">From here, you can control the elements of the homepage.</p>', MTS_THEME_TEXTDOMAIN ),
				'fields' => array(
					array(
						'id' => 'mts_featured_slider',
						'type' => 'button_set_hide_below',
						'title' => __('Homepage Slider', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('<strong>Enable or Disable</strong> homepage slider with this button. The slider will show recent articles from the selected categories.', MTS_THEME_TEXTDOMAIN ),
						'std' => '0',
                        'args' => array('hide' => 2)
						),
						array(
						'id' => 'mts_featured_slider_cat',
						'type' => 'cats_multi_select',
						'title' => __('Slider Category(s)', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a category from the drop-down menu, latest articles from this category will be shown <strong>in the slider</strong>.', MTS_THEME_TEXTDOMAIN ),
						),
                        array(
						'id' => 'mts_featured_slider_num',
						'type' => 'text',
                        'class' => 'small-text',
						'title' => __('Number of posts', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Enter the number of posts to show in the slider', MTS_THEME_TEXTDOMAIN ),
                        'std' => '3',
                        'args' => array('type' => 'number')
						),
						array(
						'id' => 'mts_featured_slider_full_width',
						'type' => 'button_set',
						'title' => __('Full width Slider', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('<strong>Enable or Disable</strong> Full width slider with this button.', MTS_THEME_TEXTDOMAIN ),
						'std' => '0'
						),
						array(
						'id' => 'mts_featured_categories',
						'type' => 'group',
						'title' => __('Featured Categories', MTS_THEME_TEXTDOMAIN) ,
						'sub_desc' => __('Select categories appearing on the homepage.', MTS_THEME_TEXTDOMAIN) ,
						'groupname' => __('Section', MTS_THEME_TEXTDOMAIN) , // Group name
						'subfields' => array(
							array(
								'id' => 'mts_featured_category',
								'type' => 'cats_select',
								'title' => __('Category', MTS_THEME_TEXTDOMAIN) ,
								'sub_desc' => __('Select a category or the latest posts for this section', MTS_THEME_TEXTDOMAIN) ,
								'std' => 'latest',
								'args' => array( 'include_latest' => 1, 'hide_empty' => 0, ),
							),
							array(
								'id' => 'mts_featured_category_layout',
								'type' => 'select',
								'title' => __('Posts Layout', MTS_THEME_TEXTDOMAIN),
								'sub_desc' => __('Select the posts layout for this section.', MTS_THEME_TEXTDOMAIN) ,
								'options' => array(
									'withsidebar' => 'Posts with sidebar',
									'smallbig'=> '1 Small and 1 Big Column',
									'grid'=> '4 Column grid',
									'list'=> 'List grid'									
								),
								'std' => 'withsidebar'
							),
							array(
								'id' => 'mts_featured_category_postsnum',
								'type' => 'text',
								'class' => 'small-text',
								'title' => __('Number of posts', MTS_THEME_TEXTDOMAIN) ,
								'sub_desc' => __('
												Enter the number of posts to show in this section.
												<br/><strong>For Latest Posts</strong>, this setting will be ignored, and number set in <a href="' . admin_url('options-reading.php') . '" target="_blank">Settings&nbsp;&gt;&nbsp;Reading</a> will be used instead.', MTS_THEME_TEXTDOMAIN) ,
								'std' => '4',
								'args' => array(
									'type' => 'number'
								)
							),
						),
						'std' => array(
							'1' => array(
								'group_title' => '',
								'group_sort' => '1',
								'mts_featured_category' => 'latest',
								'mts_featured_category_postsnum' => get_option('posts_per_page'),
								'mts_featured_category_layout' => 'list',
								'mts_featured_category_vert_postsnum' => '4'
							)
						)
					),
					array(
                        'id'       => 'mts_home_headline_meta_info',
                        'type'     => 'layout',
                        'title'    => __('HomePage Post Meta Info', MTS_THEME_TEXTDOMAIN ),
                        'sub_desc' => __('Organize how you want the post meta info to appear on the homepage', MTS_THEME_TEXTDOMAIN ),
                        'options'  => array(
                            'enabled'  => array(
                                'category' => __('Categories', MTS_THEME_TEXTDOMAIN ),
                            ),
                            'disabled' => array(
                                'author'   => __('Author Name', MTS_THEME_TEXTDOMAIN ),
                                'date'     => __('Date', MTS_THEME_TEXTDOMAIN ),
                                'comment'  => __('Comment Count', MTS_THEME_TEXTDOMAIN )
                            )
                        ),
                        'std'  => array(
                            'enabled'  => array(
                                'category' => __('Categories', MTS_THEME_TEXTDOMAIN ),
                            ),
                            'disabled' => array(
                                'author'   => __('Author Name', MTS_THEME_TEXTDOMAIN ),
                                'date'     => __('Date', MTS_THEME_TEXTDOMAIN ),
                                'comment'  => __('Comment Count', MTS_THEME_TEXTDOMAIN )
                            )
                        )
                    ),
					)
				);	
$sections[] = array(
				'icon' => 'fa fa-file-text',
				'title' => __('Single Posts', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description">From here, you can control the appearance and functionality of your single posts page.</p>', MTS_THEME_TEXTDOMAIN ),
				'fields' => array(
					array(
                        'id'       => 'mts_single_post_layout',
                        'type'     => 'layout2',
                        'title'    => __('Single Post Layout', MTS_THEME_TEXTDOMAIN ),
                        'sub_desc' => __('Customize the look of single posts', MTS_THEME_TEXTDOMAIN ),
                        'options'  => array(
                            'enabled'  => array(
                                'content'   => array(
                                	'label' 	=> __('Post Content', MTS_THEME_TEXTDOMAIN ),
                                	'subfields'	=> array(
                                		
                                	)
                                ),
                                'related'   => array(
                                	'label' 	=> __('Related Posts', MTS_THEME_TEXTDOMAIN ),
                                	'subfields'	=> array(
					        			array(
					        				'id' => 'mts_related_posts_taxonomy',
					        				'type' => 'button_set',
					        				'title' => __('Related Posts Taxonomy', MTS_THEME_TEXTDOMAIN ) ,
					        				'options' => array(
					        					'tags' => 'Tags',
					        					'categories' => 'Categories'
					        				) ,
					        				'class' => 'green',
					        				'sub_desc' => __('Related Posts based on tags or categories.', MTS_THEME_TEXTDOMAIN ) ,
					        				'std' => 'categories'
					        			),
					        			array(
					        				'id' => 'mts_related_postsnum',
					        				'type' => 'text',
					        				'class' => 'small-text',
					        				'title' => __('Number of related posts', MTS_THEME_TEXTDOMAIN ) ,
					        				'sub_desc' => __('Enter the number of posts to show in the related posts section.', MTS_THEME_TEXTDOMAIN ) ,
					        				'std' => '2',
					        				'args' => array(
					        					'type' => 'number'
					        				)
					        			),

                                	)
                                ),
                                'author'   => array(
                                	'label' 	=> __('Author Box', MTS_THEME_TEXTDOMAIN ),
                                	'subfields'	=> array(

                                	)
                                ),
                            ),
                            'disabled' => array(
                            	'tags'   => array(
                                	'label' 	=> __('Tags', MTS_THEME_TEXTDOMAIN ),
                                	'subfields'	=> array(
                                	)
                                ),
                            )
                        )
                    ),
					array(
						'id' => 'mts_breadcrumb',
						'type' => 'button_set',
						'title' => __('Breadcrumbs', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Breadcrumbs are a great way to make your site more user-friendly. You can enable them by checking this box.', MTS_THEME_TEXTDOMAIN ),
						'std' => '1'
						),
					array(
						'id' => 'mts_single_headline_meta',
						'type' => 'button_set_hide_below',
						'title' => __('Post Meta Info.', MTS_THEME_TEXTDOMAIN), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Use this button to Show or Hide Post Meta Info <strong>Author name and Categories</strong>.', MTS_THEME_TEXTDOMAIN),
						'std' => '1'
						),
						array(
 						'id' => 'mts_single_headline_meta_info',
 						'type' => 'multi_checkbox',
 						'title' => __('Meta Info to Show', MTS_THEME_TEXTDOMAIN),
 						'sub_desc' => __('Choose What Meta Info to Show.', MTS_THEME_TEXTDOMAIN),
 						'options' => array('category' => __('Categories',MTS_THEME_TEXTDOMAIN),'date' => __('Date',MTS_THEME_TEXTDOMAIN),'author' =>__('Author Name',MTS_THEME_TEXTDOMAIN)),
 						'std' => array('category' => '1', 'date' => '1', 'author' => '1')
 						),
					array(
						'id' => 'mts_author_comment',
						'type' => 'button_set',
						'title' => __('Highlight Author Comment', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Use this button to highlight author comments.', MTS_THEME_TEXTDOMAIN ),
						'std' => '1'
						),
					array(
						'id' => 'mts_comment_date',
						'type' => 'button_set',
						'title' => __('Date in Comments', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('0' => 'Off','1' => 'On'),
						'sub_desc' => __('Use this button to show the date for comments.', MTS_THEME_TEXTDOMAIN ),
						'std' => '1'
						),
					)
				);
$sections[] = array(
				'icon' => 'fa fa-group',
				'title' => __('Social Buttons', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description">Enable or disable social sharing buttons on single posts using these buttons.</p>', MTS_THEME_TEXTDOMAIN ),
				'fields' => array(
					array(
						'id' => 'mts_social_button_position',
						'type' => 'button_set',
						'title' => __('Social Sharing Buttons Position', MTS_THEME_TEXTDOMAIN ), 
						'options' => array('top' => __('Above Content', MTS_THEME_TEXTDOMAIN ), 'bottom' => __('Below Content', MTS_THEME_TEXTDOMAIN ), 'floating' => __('Floating', MTS_THEME_TEXTDOMAIN )),
						'sub_desc' => __('Choose position for Social Sharing Buttons.', MTS_THEME_TEXTDOMAIN ),
						'std' => 'floating',
						'class' => 'green'
					),
					array(
                        'id'       => 'mts_social_buttons',
                        'type'     => 'layout',
                        'title'    => __('Social Media Buttons', MTS_THEME_TEXTDOMAIN ),
                        'sub_desc' => __('Organize how you want the social sharing buttons to appear on single posts', MTS_THEME_TEXTDOMAIN ),
                        'options'  => array(
                            'enabled'  => array(
                            	'facebookshare'   => __('Facebook Share', MTS_THEME_TEXTDOMAIN ),
                            	'facebook'  => __('Facebook Like', MTS_THEME_TEXTDOMAIN ),
                                'twitter'   => __('Twitter', MTS_THEME_TEXTDOMAIN ),
                                'gplus'     => __('Google Plus', MTS_THEME_TEXTDOMAIN ),
                                'pinterest' => __('Pinterest', MTS_THEME_TEXTDOMAIN ),
                            ),
                            'disabled' => array(
                            	'linkedin'  => __('LinkedIn', MTS_THEME_TEXTDOMAIN ),
                                'stumble'   => __('StumbleUpon', MTS_THEME_TEXTDOMAIN ),
                            )
                        ),
                        'std'  => array(
                            'enabled'  => array(
                            	'facebookshare'   => __('Facebook Share', MTS_THEME_TEXTDOMAIN ),
                            	'facebook'  => __('Facebook Like', MTS_THEME_TEXTDOMAIN ),
                                'twitter'   => __('Twitter', MTS_THEME_TEXTDOMAIN ),
                                'gplus'     => __('Google Plus', MTS_THEME_TEXTDOMAIN ),
                                'pinterest' => __('Pinterest', MTS_THEME_TEXTDOMAIN ),
                            ),
                            'disabled' => array(
                            	'linkedin'  => __('LinkedIn', MTS_THEME_TEXTDOMAIN ),
                                'stumble'   => __('StumbleUpon', MTS_THEME_TEXTDOMAIN ),
                            )
                        )
                    ),
					array(
                     	'id' => 'mts_footer_social',
                     	'title' => __('Footer Social Icons', MTS_THEME_TEXTDOMAIN), 
                     	'sub_desc' => __( 'Add Social Media icons in Footer.', MTS_THEME_TEXTDOMAIN ),
                     	'type' => 'group',
                     	'groupname' => __('Footer Icons', MTS_THEME_TEXTDOMAIN), // Group name
                     	'subfields' => 
                            array(
                                array(
                                    'id' => 'mts_footer_icon_title',
            						'type' => 'text',
            						'title' => __('Title', MTS_THEME_TEXTDOMAIN), 
            						),
								array(
                                    'id' => 'mts_footer_icon',
            						'type' => 'icon_select',
            						'title' => __('Icon', MTS_THEME_TEXTDOMAIN)
            						),
								array(
                                    'id' => 'mts_footer_icon_link',
            						'type' => 'text',
            						'title' => __('URL', MTS_THEME_TEXTDOMAIN), 
            						),
								array(
									'id' => 'mts_footer_icon_color',
									'type' => 'color',
									'title' => __('Icon Color', MTS_THEME_TEXTDOMAIN), 
									'sub_desc' => __('Pick a color for the icon.', MTS_THEME_TEXTDOMAIN),
									'std' => '#808080'
									),
			                	),
                        'std' => array(
        					'facebook' => array(
        						'group_title' => 'Facebook',
        						'group_sort' => '1',
        						'mts_footer_icon_title' => 'Facebook',
        						'mts_footer_icon' => 'facebook',
        						'mts_footer_icon_link' => '#',
        						'mts_footer_icon_color' => '#808080'
        					),
        					'twitter' => array(
        						'group_title' => 'Twitter',
        						'group_sort' => '2',
        						'mts_footer_icon_title' => 'Twitter',
        						'mts_footer_icon' => 'twitter',
        						'mts_footer_icon_link' => '#',
        						'mts_footer_icon_color' => '#808080'
        					),
        					'gplus' => array(
        						'group_title' => 'Google Plus',
        						'group_sort' => '3',
        						'mts_footer_icon_title' => 'Google Plus',
        						'mts_footer_icon' => 'google-plus',
        						'mts_footer_icon_link' => '#',
        						'mts_footer_icon_color' => '#808080'
        					),
        					'youtube' => array(
        						'group_title' => 'YouTube',
        						'group_sort' => '4',
        						'mts_footer_icon_title' => 'YouTube',
        						'mts_footer_icon' => 'youtube-play',
        						'mts_footer_icon_link' => '#',
        						'mts_footer_icon_color' => '#808080'
        					)
        				)
                    ),
				)
			);
$sections[] = array(
				'icon' => 'fa fa-bar-chart-o',
				'title' => __('Ad Management', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description">Now, ad management is easy with our options panel. You can control everything from here, without using separate plugins.</p>', MTS_THEME_TEXTDOMAIN ),
				'fields' => array(
					array(
						'id' => 'mts_posttop_adcode',
						'type' => 'textarea',
						'title' => __('Below Post Title', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below your article title on single posts.', MTS_THEME_TEXTDOMAIN )
						),
					array(
						'id' => 'mts_posttop_adcode_time',
						'type' => 'text',
						'title' => __('Show After X Days', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', MTS_THEME_TEXTDOMAIN ),
						'validate' => 'numeric',
						'std' => '0',
						'class' => 'small-text',
                        'args' => array('type' => 'number')
						),
					array(
						'id' => 'mts_postend_adcode',
						'type' => 'textarea',
						'title' => __('Below Post Content', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below the post content on single posts.', MTS_THEME_TEXTDOMAIN )
						),
					array(
						'id' => 'mts_postend_adcode_time',
						'type' => 'text',
						'title' => __('Show After X Days', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', MTS_THEME_TEXTDOMAIN ),
						'validate' => 'numeric',
						'std' => '0',
						'class' => 'small-text',
                        'args' => array('type' => 'number')
						),
					)
				);
$sections[] = array(
				'icon' => 'fa fa-columns',
				'title' => __('Sidebars', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description">Now you have full control over the sidebars. Here you can manage sidebars and select one for each section of your site, or select a custom sidebar on a per-post basis in the post editor.<br></p>', MTS_THEME_TEXTDOMAIN ),
                'fields' => array(
                    array(
                        'id'        => 'mts_custom_sidebars',
                        'type'      => 'group', //doesn't need to be called for callback fields
                        'title'     => __('Custom Sidebars', MTS_THEME_TEXTDOMAIN ), 
                        'sub_desc'  => __('Add custom sidebars. <strong style="font-weight: 800;">You need to save the changes to use the sidebars in the dropdowns below.</strong><br />You can add content to the sidebars in Appearance &gt; Widgets.', MTS_THEME_TEXTDOMAIN ),
                        'groupname' => __('Sidebar', MTS_THEME_TEXTDOMAIN ), // Group name
                        'subfields' => 
                            array(
                                array(
                                    'id' => 'mts_custom_sidebar_name',
            						'type' => 'text',
            						'title' => __('Name', MTS_THEME_TEXTDOMAIN ), 
            						'sub_desc' => __('Example: Homepage Sidebar', MTS_THEME_TEXTDOMAIN )
            						),	
                                array(
                                    'id' => 'mts_custom_sidebar_id',
            						'type' => 'text',
            						'title' => __('ID', MTS_THEME_TEXTDOMAIN ), 
            						'sub_desc' => __('Enter a unique ID for the sidebar. Use only alphanumeric characters, underscores (_) and dashes (-), eg. "sidebar-home"', MTS_THEME_TEXTDOMAIN ),
            						'std' => 'sidebar-'
            						),
                            ),
                        ),
                    array(
						'id' => 'mts_sidebar_for_home',
						'type' => 'sidebars_select',
						'title' => __('Homepage', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the homepage.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    array(
						'id' => 'mts_sidebar_for_post',
						'type' => 'sidebars_select',
						'title' => __('Single Post', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the single posts. If a post has a custom sidebar set, it will override this.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    array(
						'id' => 'mts_sidebar_for_page',
						'type' => 'sidebars_select',
						'title' => __('Single Page', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the single pages. If a page has a custom sidebar set, it will override this.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    array(
						'id' => 'mts_sidebar_for_archive',
						'type' => 'sidebars_select',
						'title' => __('Archive', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the archives. Specific archive sidebars will override this setting (see below).', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    array(
						'id' => 'mts_sidebar_for_category',
						'type' => 'sidebars_select',
						'title' => __('Category Archive', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the category archives.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    array(
						'id' => 'mts_sidebar_for_tag',
						'type' => 'sidebars_select',
						'title' => __('Tag Archive', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the tag archives.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    array(
						'id' => 'mts_sidebar_for_date',
						'type' => 'sidebars_select',
						'title' => __('Date Archive', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the date archives.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    array(
						'id' => 'mts_sidebar_for_author',
						'type' => 'sidebars_select',
						'title' => __('Author Archive', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the author archives.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    array(
						'id' => 'mts_sidebar_for_search',
						'type' => 'sidebars_select',
						'title' => __('Search', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the search results.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    array(
						'id' => 'mts_sidebar_for_notfound',
						'type' => 'sidebars_select',
						'title' => __('404 Error', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for the 404 Not found pages.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => ''
						),
                    
                    array(
						'id' => 'mts_sidebar_for_shop',
						'type' => 'sidebars_select',
						'title' => __('Shop Pages', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for Shop main page and product archive pages (WooCommerce plugin must be enabled). Default is <strong>Shop Page Sidebar</strong>.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => 'shop-sidebar'
						),
                    array(
						'id' => 'mts_sidebar_for_product',
						'type' => 'sidebars_select',
						'title' => __('Single Product', MTS_THEME_TEXTDOMAIN ), 
						'sub_desc' => __('Select a sidebar for single products (WooCommerce plugin must be enabled). Default is <strong>Single Product Sidebar</strong>.', MTS_THEME_TEXTDOMAIN ),
                        'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
                        'std' => 'product-sidebar'
						),
                    ),
				);
//$sections[] = array(
//				'icon' => NHP_OPTIONS_URL.'img/glyphicons/fontsetting.png',
//				'title' => __('Fonts', MTS_THEME_TEXTDOMAIN ),
//				'desc' => __('<p class="description"><div class="controls">You can find theme font options under the Appearance Section named <a href="themes.php?page=typography"><b>Theme Typography</b></a>, which will allow you to configure the typography used on your site.<br></div></p>', MTS_THEME_TEXTDOMAIN ),
//				);
$sections[] = array(
				'icon' => 'fa fa-list-alt',
				'title' => __('Navigation', MTS_THEME_TEXTDOMAIN ),
				'desc' => __('<p class="description"><div class="controls">Navigation settings can now be modified from the <a href="nav-menus.php"><b>Menus Section</b></a>.<br></div></p>', MTS_THEME_TEXTDOMAIN )
				);
				
				
	$tabs = array();
    
    $args['presets'] = array();
    include('theme-presets.php');
    
	global $NHP_Options;
	$NHP_Options = new NHP_Options($sections, $args, $tabs);

}//function
add_action('init', 'setup_framework_options', 0);

/*
 * 
 * Custom function for the callback referenced above
 *
 */
function my_custom_field($field, $value){
	print_r($field);
	print_r($value);

}//function

/*
 * 
 * Custom function for the callback validation referenced above
 *
 */
function validate_callback_function($field, $value, $existing_value){
	
	$error = false;
	$value =  'just testing';
	/*
	do your validation
	
	if(something){
		$value = $value;
	}elseif(somthing else){
		$error = true;
		$value = $existing_value;
		$field['msg'] = 'your custom error message';
	}
	*/
	$return['value'] = $value;
	if($error == true){
		$return['error'] = $field;
	}
	return $return;
	
}//function

/*--------------------------------------------------------------------
 * 
 * Default Font Settings
 *
 --------------------------------------------------------------------*/
if(function_exists('mts_register_typography')) { 
  mts_register_typography(array(
    'navigation_font' => array(
      'preview_text' => __('Navigation Font', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'dark',
      'font_family' => 'Kreon',
      'font_variant' => '700',
      'font_size' => '18px',
      'font_color' => '#808080',
      'css_selectors' => '#primary-navigation a'
    ),
    'home_title_font' => array(
      'preview_text' => __('Home Article Title', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_size' => '22px',
	  'font_variant' => '700',
      'font_color' => '#151515',
      'css_selectors' => '.latestPost .title a'
    ),
    'single_title_font' => array(
      'preview_text' => __('Single Article Title', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_size' => '28px',
	  'font_variant' => '700',
      'font_color' => '#151515',
      'css_selectors' => '.single-title'
    ),
    'content_font' => array(
      'preview_text' => __('Content Font', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'ABeeZee',
      'font_size' => '16px',
	  'font_variant' => 'normal',
      'font_color' => '#808080',
      'css_selectors' => 'body'
    ),
    'widget_title' => array(
      'preview_text' => __('Widget Headline', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_size' => '22px',
	  'font_variant' => '700',
      'font_color' => '#151515',
      'css_selectors' => '.widget h3'
    ),
    'widget_article_title' => array(
      'preview_text' => __('Widget Article Title', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'ABeeZee',
      'font_size' => '15px',
	  'font_variant' => 'normal',
      'font_color' => '#151515',
      'css_selectors' => '.widget .post-title a, .wpt_widget_content .entry-title a'
    ),
	'widget_font' => array(
      'preview_text' => __('Widget Font', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_variant' => 'normal',
      'font_size' => '16px',
      'font_color' => '#808080',
      'css_selectors' => '.widget'
    ),
    'widget_postinfo_font' => array(
      'preview_text' => __('Widget Post info Font', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'ABeeZee',
      'font_variant' => 'normal',
      'font_size' => '13px',
      'font_color' => '#808080',
      'css_selectors' => '#sidebar .widget .post-info'
    ),
    'footer_heading' => array(
      'preview_text' => __('Footer Widget Heading', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_variant' => '700',
      'font_size' => '22px',
      'font_color' => '#151515',
      'css_selectors' => '#site-footer .widget h3'
    ),
	'footer_font' => array(
      'preview_text' => __('Footer Font', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'ABeeZee',
      'font_variant' => 'normal',
      'font_size' => '16px',
      'font_color' => '#808080',
      'css_selectors' => '#site-footer .widget'
    ),
    'copyright_font' => array(
      'preview_text' => __('Copyright Font', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'ABeeZee',
      'font_variant' => 'normal',
      'font_size' => '13px',
      'font_color' => '#808080',
      'css_selectors' => '#site-footer .toggle-menu .toggle-caret, #copyright-note > div'
    ),
    'submit_button' => array(
      'preview_text' => __('Buttons', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_variant' => '700',
      'font_size' => '16px',
      'font_color' => '#fff',
      'css_selectors' => '.reply a, #commentform input#submit, .contact-form input[type="submit"]'
    ),
    'h1_headline' => array(
      'preview_text' => __('Content H1', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_variant' => '700',
      'font_size' => '28px',
      'font_color' => '#151515',
      'css_selectors' => 'h1'
    ),
	'h2_headline' => array(
      'preview_text' => __('Content H2', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_variant' => '700',
      'font_size' => '24px',
      'font_color' => '#151515',
      'css_selectors' => 'h2'
    ),
	'h3_headline' => array(
      'preview_text' => __('Content H3', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_variant' => '700',
      'font_size' => '22px',
      'font_color' => '#151515',
      'css_selectors' => 'h3'
    ),
	'h4_headline' => array(
      'preview_text' => __('Content H4', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_variant' => '700',
      'font_size' => '20px',
      'font_color' => '#151515',
      'css_selectors' => 'h4'
    ),
	'h5_headline' => array(
      'preview_text' => __('Content H5', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_variant' => '700',
      'font_size' => '18px',
      'font_color' => '#151515',
      'css_selectors' => 'h5'
    ),
	'h6_headline' => array(
      'preview_text' => __('Content H6', MTS_THEME_TEXTDOMAIN),
      'preview_color' => 'light',
      'font_family' => 'Kreon',
      'font_variant' => '700',
      'font_size' => '16px',
      'font_color' => '#151515',
      'css_selectors' => 'h6'
    )
  ));
}

?>